==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ImmutabilitySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs.builder
import com.pulumi.azurenative.dataprotection.kotlin.enums.ImmutabilityState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Immutability Settings at vault level
 * @property state Immutability state
 */
public data class ImmutabilitySettingsArgs(
    public val state: Output<Either<String, ImmutabilityState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs =
        com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ImmutabilitySettingsArgs].
 */
@PulumiTagMarker
public class ImmutabilitySettingsArgsBuilder internal constructor() {
    private var state: Output<Either<String, ImmutabilityState>>? = null

    /**
     * @param value Immutability state
     */
    @JvmName("qpuloesshqpiowfg")
    public suspend fun state(`value`: Output<Either<String, ImmutabilityState>>) {
        this.state = value
    }

    /**
     * @param value Immutability state
     */
    @JvmName("tjwykyvglpttuafi")
    public suspend fun state(`value`: Either<String, ImmutabilityState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Immutability state
     */
    @JvmName("adcuhpbiywniefxt")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ImmutabilityState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Immutability state
     */
    @JvmName("qjxmkvknobyqmukd")
    public fun state(`value`: ImmutabilityState) {
        val toBeMapped = Either.ofRight<String, ImmutabilityState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): ImmutabilitySettingsArgs = ImmutabilitySettingsArgs(
        state = state,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ImmutabilitySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs.builder
import com.pulumi.azurenative.dataprotection.kotlin.enums.ImmutabilityState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Immutability Settings at vault level
 * @property state Immutability state
 */
public data class ImmutabilitySettingsArgs(
    public val state: Output<Either<String, ImmutabilityState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs =
        com.pulumi.azurenative.dataprotection.inputs.ImmutabilitySettingsArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ImmutabilitySettingsArgs].
 */
@PulumiTagMarker
public class ImmutabilitySettingsArgsBuilder internal constructor() {
    private var state: Output<Either<String, ImmutabilityState>>? = null

    /**
     * @param value Immutability state
     */
    @JvmName("nbudhritmlnpsgau")
    public suspend fun state(`value`: Output<Either<String, ImmutabilityState>>) {
        this.state = value
    }

    /**
     * @param value Immutability state
     */
    @JvmName("dhuupdwsnlnrhacw")
    public suspend fun state(`value`: Either<String, ImmutabilityState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Immutability state
     */
    @JvmName("iqlcsiavcpurfakq")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ImmutabilityState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Immutability state
     */
    @JvmName("tndcqmbombalnvck")
    public fun state(`value`: ImmutabilityState) {
        val toBeMapped = Either.ofRight<String, ImmutabilityState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): ImmutabilitySettingsArgs = ImmutabilitySettingsArgs(
        state = state,
    )
}
